@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: class.cc,v 1.5 2005/01/21 12:48:05 murrayc Exp $ */
+/* $Id: class.cc,v 1.5.4.1 2006/05/10 13:12:39 murrayc Exp $ */
 
 /* Copyright (C) 1998-2002 The gtkmm Development Team
  *
@@ -108,8 +108,10 @@ void Class::custom_class_init_function(void* g_class, void* class_data)
 
   GObjectClass *const gobject_class = static_cast<GObjectClass*>(g_class);
 
+#ifdef GLIBMM_PROPERTIES_ENABLED
   gobject_class->get_property = &Glib::custom_get_property_callback;
   gobject_class->set_property = &Glib::custom_set_property_callback;
+#endif //GLIBMM_PROPERTIES_ENABLED
 }
 
 } // namespace Glib
