@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_USTRING_H
 #define _GLIBMM_USTRING_H
 
-/* $Id: ustring.h,v 1.12 2005/01/21 19:26:04 murrayc Exp $ */
+/* $Id: ustring.h,v 1.12.4.2 2006/04/12 12:50:10 murrayc Exp $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -233,11 +233,11 @@ public:
 #endif /* GLIBMM_HAVE_SUN_REVERSE_ITERATOR */
 
 #ifdef GLIBMM_HAVE_ALLOWS_STATIC_INLINE_NPOS
-  static const size_type npos = std::string::npos;
+  static GLIBMM_API const size_type npos = std::string::npos;
 #else
   //The IRIX MipsPro compiler says "The indicated constant value is not known",
   //so we need to initalize the static member data elsewhere.
-  static const size_type npos;
+  static GLIBMM_API const size_type npos;
 #endif
 
   /*! Default constructor, which creates an empty string.
@@ -570,7 +570,7 @@ public:
 //! @{
 
   /*! Returns a new UTF-8 string with all characters characters converted to
-   * their lowercase equivalent, while honoring the current locale.  The
+   * their uppercase equivalent, while honoring the current locale.  The
    * resulting string may change in the number of bytes as well as in the
    * number of characters.  For instance, the German sharp&nbsp;s
    * <tt>&quot;&szlig;&quot;</tt> will be replaced by two characters
